.. _index:

Afmformats is a Python library for reading atomic force microscopy (AFM)
data file formats.
This is the documentation of afmformats version |release|.


Documentation
=============

.. toctree::
   :maxdepth: 3

   sec_getting_started
   sec_examples
   sec_advanced_usage
   sec_new_formats

.. toctree::
   :maxdepth: 1

   Code reference <sec_api/afmformats>
   sec_changelog
   sec_z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
